@@ -1,11 +1,5 @@
 #!/usr/bin/env python3
 
-# import os
-# import sys
-# import logging
-# import inspect
-# import gzip
-
 import argparse
 
 from enum import Enum
@@ -15,17 +9,16 @@ from .log import setup_logging
 
 import os
 
-__version__ = "1.0"
+from . import __version__
 
 logger = setup_logging(__name__)
 
 ##############################################################################
 
 
-
 class Mode(Enum):
-    minify = 'minify'
-    beautify = 'beautify'
+    minify = "minify"
+    beautify = "beautify"
 
     def __str__(self):
         return self.value
