@@ -59,8 +59,8 @@ class Processor:
         return True, None
 
     def prepare_handlers(self):
-        self.handlers={}
-        handlers_mod = importlib.import_module('.handlers', 'web_minify')
+        self.handlers = {}
+        handlers_mod = importlib.import_module(".handlers", "web_minify")
         for name, cls in handlers_mod.__dict__.items():
             if isinstance(cls, type):
                 handler = cls(self.settings)
@@ -133,7 +133,7 @@ class Processor:
             was_copied = True
         else:
             # logger.info(f"SUPPOSED TO PROCESS: {input_path} ({extension})")
-            tup=handler.process(original_content)
+            tup = handler.process(original_content)
             logger.info(f"TUP: ({tup}) with {handler.extensions()}")
             _processed_content, handler_errors = tup
             processed_content = _processed_content
@@ -156,7 +156,6 @@ class Processor:
         # All went well, go home happy!
         return True, was_copied, False, None
 
-
     def process_files_list(self, list):
         start_time = datetime.datetime.now()
         success_count = 0
